# Autogenerated from HTML specification. Edits may be lost.

htmlelement = [
    (str, 'title', 'title'),
    (str, 'lang', 'lang'),
    (bool, 'translate', 'translate'),
    (str, 'dir', 'dir'),
    (str, 'dataset', 'dataset'),
    (bool, 'hidden', 'hidden'),
    (int, 'tabindex', 'tabIndex'),
    (str, 'accesskey', 'accessKey'),
    (bool, 'draggable', 'draggable'),
    (str, 'dropzone', 'dropzone'),
    (str, 'contextmenu', 'contextMenu'),
    (bool, 'spellcheck', 'spellcheck'),
    (str, 'onabort', 'onabort'),
    (str, 'onblur', 'onblur'),
    (str, 'oncancel', 'oncancel'),
    (str, 'oncanplay', 'oncanplay'),
    (str, 'oncanplaythrough', 'oncanplaythrough'),
    (str, 'onchange', 'onchange'),
    (str, 'onclick', 'onclick'),
    (str, 'onclose', 'onclose'),
    (str, 'oncontextmenu', 'oncontextmenu'),
    (str, 'oncuechange', 'oncuechange'),
    (str, 'ondblclick', 'ondblclick'),
    (str, 'ondrag', 'ondrag'),
    (str, 'ondragend', 'ondragend'),
    (str, 'ondragenter', 'ondragenter'),
    (str, 'ondragexit', 'ondragexit'),
    (str, 'ondragleave', 'ondragleave'),
    (str, 'ondragover', 'ondragover'),
    (str, 'ondragstart', 'ondragstart'),
    (str, 'ondrop', 'ondrop'),
    (str, 'ondurationchange', 'ondurationchange'),
    (str, 'onemptied', 'onemptied'),
    (str, 'onended', 'onended'),
    (str, 'onerror', 'onerror'),
    (str, 'onfocus', 'onfocus'),
    (str, 'oninput', 'oninput'),
    (str, 'oninvalid', 'oninvalid'),
    (str, 'onkeydown', 'onkeydown'),
    (str, 'onkeypress', 'onkeypress'),
    (str, 'onkeyup', 'onkeyup'),
    (str, 'onload', 'onload'),
    (str, 'onloadeddata', 'onloadeddata'),
    (str, 'onloadedmetadata', 'onloadedmetadata'),
    (str, 'onloadstart', 'onloadstart'),
    (str, 'onmousedown', 'onmousedown'),
    (str, 'onmouseenter', 'onmouseenter'),
    (str, 'onmouseleave', 'onmouseleave'),
    (str, 'onmousemove', 'onmousemove'),
    (str, 'onmouseout', 'onmouseout'),
    (str, 'onmouseover', 'onmouseover'),
    (str, 'onmouseup', 'onmouseup'),
    (str, 'onwheel', 'onwheel'),
    (str, 'onpause', 'onpause'),
    (str, 'onplay', 'onplay'),
    (str, 'onplaying', 'onplaying'),
    (str, 'onprogress', 'onprogress'),
    (str, 'onratechange', 'onratechange'),
    (str, 'onreset', 'onreset'),
    (str, 'onresize', 'onresize'),
    (str, 'onscroll', 'onscroll'),
    (str, 'onseeked', 'onseeked'),
    (str, 'onseeking', 'onseeking'),
    (str, 'onselect', 'onselect'),
    (str, 'onshow', 'onshow'),
    (str, 'onstalled', 'onstalled'),
    (str, 'onsubmit', 'onsubmit'),
    (str, 'onsuspend', 'onsuspend'),
    (str, 'ontimeupdate', 'ontimeupdate'),
    (str, 'ontoggle', 'ontoggle'),
    (str, 'onvolumechange', 'onvolumechange'),
    (str, 'onwaiting', 'onwaiting'),
    (str, 'oncopy', 'oncopy'),
    (str, 'oncut', 'oncut'),
    (str, 'onpaste', 'onpaste'),
    (str, 'content_editable', 'contentEditable'),
    (bool, 'content_editable', 'isContentEditable')
]

HTMLElementCollection = []

font = [
    (str, 'color', 'color'),
    (str, 'face', 'face')
]

FontCollection = []

directory = [
    (bool, 'compact', 'compact')
]

DirectoryCollection = []

frameset = [
    (str, 'cols', 'cols'),
    (str, 'onafterprint', 'onafterprint'),
    (str, 'onbeforeprint', 'onbeforeprint'),
    (str, 'onbeforeunload', 'onbeforeunload'),
    (str, 'onhashchange', 'onhashchange'),
    (str, 'onlanguagechange', 'onlanguagechange'),
    (str, 'onmessage', 'onmessage'),
    (str, 'onoffline', 'onoffline'),
    (str, 'ononline', 'ononline'),
    (str, 'onpagehide', 'onpagehide'),
    (str, 'onpageshow', 'onpageshow'),
    (str, 'onrejectionhandled', 'onrejectionhandled'),
    (str, 'onpopstate', 'onpopstate'),
    (str, 'onstorage', 'onstorage'),
    (str, 'onunhandledrejection', 'onunhandledrejection'),
    (str, 'onunload', 'onunload')
]

FrameSetCollection = []

marquee = [
    (str, 'behavior', 'behavior'),
    (str, 'bgcolor', 'bgColor'),
    (str, 'direction', 'direction'),
    (int, 'hspace', 'hspace'),
    (int, 'loop', 'loop'),
    (int, 'scrollamount', 'scrollAmount'),
    (int, 'scrolldelay', 'scrollDelay'),
    (bool, 'truespeed', 'trueSpeed'),
    (int, 'vspace', 'vspace'),
    (str, 'onbounce', 'onbounce'),
    (str, 'onfinish', 'onfinish'),
    (str, 'onstart', 'onstart')
]

MarqueeCollection = []

applet = [
    (str, 'align', 'align'),
    (str, 'alt', 'alt'),
    (str, 'archive', 'archive'),
    (str, 'code', 'code'),
    (str, 'codebase', 'codeBase'),
    (int, 'hspace', 'hspace'),
    (str, 'name', 'name'),
    (str, 'object', 'object'),
    (int, 'vspace', 'vspace')
]

AppletCollection = []

Canvas = []

CanvasCollection = []

template = [
    (str, 'content', 'content')
]

TemplateCollection = []

script = [
    (str, 'src', 'src'),
    (str, 'type', 'type'),
    (str, 'charset', 'charset'),
    (bool, 'async', 'async'),
    (bool, 'defer', 'defer'),
    (str, 'crossorigin', 'crossOrigin'),
    (str, 'nonce', 'nonce'),
    (str, 'event', 'event'),
    (str, 'for', 'htmlFor')
]

ScriptCollection = []

menuitem = [
    (str, 'type', 'type'),
    (str, 'label', 'label'),
    (str, 'icon', 'icon'),
    (bool, 'disabled', 'disabled'),
    (bool, 'checked', 'checked'),
    (str, 'radiogroup', 'radiogroup'),
    (bool, 'default', 'default')
]

MenuItemCollection = []

menu = [
    (str, 'type', 'type'),
    (str, 'label', 'label'),
    (bool, 'compact', 'compact')
]

MenuCollection = []

details = [
    (bool, 'open', 'open')
]

DetailsCollection = []

legend = [
    (str, 'form', 'form'),
    (str, 'align', 'align')
]

LegendCollection = []

fieldset = [
    (bool, 'disabled', 'disabled'),
    (str, 'form', 'form'),
    (str, 'name', 'name'),
    (str, 'type', 'type'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage')
]

FieldSetCollection = []

meter = [
    (float, 'value', 'value'),
    (float, 'min', 'min'),
    (float, 'max', 'max'),
    (float, 'low', 'low'),
    (float, 'high', 'high'),
    (float, 'optimum', 'optimum'),
    (str, 'labels', 'labels')
]

MeterCollection = []

progress = [
    (float, 'value', 'value'),
    (float, 'max', 'max'),
    (float, 'position', 'position'),
    (str, 'labels', 'labels')
]

ProgressCollection = []

output = [
    (str, 'for', 'htmlFor'),
    (str, 'form', 'form'),
    (str, 'name', 'name'),
    (str, 'type', 'type'),
    (str, 'defaultvalue', 'defaultValue'),
    (str, 'value', 'value'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage'),
    (str, 'labels', 'labels')
]

OutputCollection = []

keygen = [
    (bool, 'autofocus', 'autofocus'),
    (str, 'challenge', 'challenge'),
    (bool, 'disabled', 'disabled'),
    (str, 'form', 'form'),
    (str, 'keytype', 'keytype'),
    (str, 'name', 'name'),
    (str, 'type', 'type'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage'),
    (str, 'labels', 'labels')
]

KeygenCollection = []

textarea = [
    (str, 'autocomplete', 'autocomplete'),
    (bool, 'autofocus', 'autofocus'),
    (int, 'cols', 'cols'),
    (str, 'dirname', 'dirName'),
    (bool, 'disabled', 'disabled'),
    (str, 'form', 'form'),
    (str, 'inputmode', 'inputMode'),
    (int, 'maxlength', 'maxLength'),
    (int, 'minlength', 'minLength'),
    (str, 'name', 'name'),
    (str, 'placeholder', 'placeholder'),
    (bool, 'readonly', 'readOnly'),
    (bool, 'required', 'required'),
    (str, 'wrap', 'wrap'),
    (str, 'type', 'type'),
    (str, 'defaultvalue', 'defaultValue'),
    (int, 'textlength', 'textLength'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage'),
    (str, 'labels', 'labels'),
    (int, 'selectionstart', 'selectionStart'),
    (int, 'selectionend', 'selectionEnd'),
    (str, 'selectiondirection', 'selectionDirection')
]

TextAreaCollection = []

option = [
    (bool, 'disabled', 'disabled'),
    (str, 'form', 'form'),
    (str, 'label', 'label'),
    (bool, 'defaultselected', 'defaultSelected'),
    (bool, 'selected', 'selected'),
    (str, 'value', 'value'),
    (int, 'index', 'index')
]

OptionCollection = []

optgroup = [
    (bool, 'disabled', 'disabled'),
    (str, 'label', 'label')
]

OptGroupCollection = []

datalist = [
    (str, 'options', 'options')
]

DataListCollection = []

select = [
    (str, 'autocomplete', 'autocomplete'),
    (bool, 'autofocus', 'autofocus'),
    (bool, 'disabled', 'disabled'),
    (str, 'form', 'form'),
    (bool, 'multiple', 'multiple'),
    (str, 'name', 'name'),
    (bool, 'required', 'required'),
    (str, 'type', 'type'),
    (str, 'element_options', 'options'),
    (int, 'length', 'length'),
    (str, 'selectedoptions', 'selectedOptions'),
    (int, 'selectedindex', 'selectedIndex'),
    (str, 'value', 'value'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage'),
    (str, 'labels', 'labels')
]

SelectCollection = []

button = [
    (bool, 'autofocus', 'autofocus'),
    (bool, 'disabled', 'disabled'),
    (str, 'form', 'form'),
    (str, 'formaction', 'formAction'),
    (str, 'formenctype', 'formEnctype'),
    (str, 'formmethod', 'formMethod'),
    (bool, 'formnovalidate', 'formNoValidate'),
    (str, 'formtarget', 'formTarget'),
    (str, 'name', 'name'),
    (str, 'type', 'type'),
    (str, 'value', 'value'),
    (str, 'menu', 'menu'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage'),
    (str, 'labels', 'labels')
]

ButtonCollection = []

input = [
    (str, 'accept', 'accept'),
    (str, 'alt', 'alt'),
    (str, 'autocomplete', 'autocomplete'),
    (bool, 'autofocus', 'autofocus'),
    (bool, 'defaultchecked', 'defaultChecked'),
    (bool, 'checked', 'checked'),
    (str, 'dirname', 'dirName'),
    (bool, 'disabled', 'disabled'),
    (str, 'form', 'form'),
    (str, 'files', 'files'),
    (str, 'formaction', 'formAction'),
    (str, 'formenctype', 'formEnctype'),
    (str, 'formmethod', 'formMethod'),
    (bool, 'formnovalidate', 'formNoValidate'),
    (str, 'formtarget', 'formTarget'),
    (bool, 'indeterminate', 'indeterminate'),
    (str, 'inputmode', 'inputMode'),
    (str, 'list', 'list'),
    (str, 'max', 'max'),
    (int, 'maxlength', 'maxLength'),
    (str, 'min', 'min'),
    (int, 'minlength', 'minLength'),
    (bool, 'multiple', 'multiple'),
    (str, 'name', 'name'),
    (str, 'pattern', 'pattern'),
    (str, 'placeholder', 'placeholder'),
    (bool, 'readonly', 'readOnly'),
    (bool, 'required', 'required'),
    (str, 'src', 'src'),
    (str, 'step', 'step'),
    (str, 'type', 'type'),
    (str, 'defaultvalue', 'defaultValue'),
    (str, 'value', 'value'),
    (str, 'valueasdate', 'valueAsDate'),
    (float, 'valueasnumber', 'valueAsNumber'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage'),
    (str, 'labels', 'labels'),
    (int, 'selectionstart', 'selectionStart'),
    (int, 'selectionend', 'selectionEnd'),
    (str, 'selectiondirection', 'selectionDirection'),
    (str, 'align', 'align'),
    (str, 'usemap', 'useMap')
]

InputCollection = []

label = [
    (str, 'form', 'form'),
    (str, 'for', 'htmlFor'),
    (str, 'control', 'control')
]

LabelCollection = []

form = [
    (str, 'accept_charset', 'acceptCharset'),
    (str, 'action', 'action'),
    (str, 'autocomplete', 'autocomplete'),
    (str, 'enctype', 'enctype'),
    (str, 'encoding', 'encoding'),
    (str, 'method', 'method'),
    (str, 'name', 'name'),
    (bool, 'novalidate', 'noValidate'),
    (str, 'target', 'target'),
    (int, 'length', 'length')
]

FormCollection = []

tablecell = [
    (int, 'colspan', 'colSpan'),
    (int, 'rowspan', 'rowSpan'),
    (str, 'headers', 'headers'),
    (int, 'cellindex', 'cellIndex'),
    (str, 'align', 'align'),
    (str, 'axis', 'axis'),
    (str, 'ch', 'ch'),
    (str, 'choff', 'chOff'),
    (bool, 'nowrap', 'noWrap'),
    (str, 'valign', 'vAlign'),
    (str, 'bgcolor', 'bgColor')
]

TableCellCollection = []

tableheadercell = [
    (str, 'scope', 'scope'),
    (str, 'abbr', 'abbr')
]

TableHeaderCellCollection = []

tabledatacell = [
    (str, 'abbr', 'abbr')
]

TableDataCellCollection = []

tablerow = [
    (int, 'rowindex', 'rowIndex'),
    (int, 'sectionrowindex', 'sectionRowIndex'),
    (str, 'align', 'align'),
    (str, 'ch', 'ch'),
    (str, 'choff', 'chOff'),
    (str, 'valign', 'vAlign'),
    (str, 'bgcolor', 'bgColor')
]

TableRowCollection = []

tablesection = [
    (str, 'align', 'align'),
    (str, 'ch', 'ch'),
    (str, 'choff', 'chOff'),
    (str, 'valign', 'vAlign')
]

TableSectionCollection = []

tablecol = [
    (str, 'align', 'align'),
    (str, 'ch', 'ch'),
    (str, 'choff', 'chOff'),
    (str, 'valign', 'vAlign')
]

TableColCollection = []

tablecaption = [
    (str, 'align', 'align')
]

TableCaptionCollection = []

table = [
    (str, 'caption', 'caption'),
    (str, 'tbodies', 'tBodies'),
    (str, 'align', 'align'),
    (str, 'border', 'border'),
    (str, 'frame', 'frame'),
    (str, 'rules', 'rules'),
    (str, 'summary', 'summary'),
    (str, 'bgcolor', 'bgColor'),
    (str, 'cellpadding', 'cellPadding'),
    (str, 'cellspacing', 'cellSpacing')
]

TableCollection = []

area = [
    (str, 'alt', 'alt'),
    (str, 'coords', 'coords'),
    (str, 'shape', 'shape'),
    (str, 'target', 'target'),
    (str, 'download', 'download'),
    (str, 'rel', 'rel'),
    (str, 'rellist', 'relList'),
    (str, 'hreflang', 'hreflang'),
    (str, 'type', 'type'),
    (bool, 'nohref', 'noHref'),
    (str, 'href', 'href'),
    (str, 'origin', 'origin'),
    (str, 'protocol', 'protocol'),
    (str, 'username', 'username'),
    (str, 'password', 'password'),
    (str, 'host', 'host'),
    (str, 'hostname', 'hostname'),
    (str, 'port', 'port'),
    (str, 'pathname', 'pathname'),
    (str, 'search', 'search')
]

AreaCollection = []

map = [
    (str, 'name', 'name'),
    (str, 'areas', 'areas'),
    (str, 'images', 'images')
]

MapCollection = []

media = [
    (str, 'error', 'error'),
    (str, 'src', 'src'),
    (str, 'srcobject', 'srcObject'),
    (str, 'currentsrc', 'currentSrc'),
    (str, 'crossorigin', 'crossOrigin'),
    (int, 'networkstate', 'networkState'),
    (str, 'preload', 'preload'),
    (str, 'buffered', 'buffered'),
    (int, 'readystate', 'readyState'),
    (bool, 'seeking', 'seeking'),
    (float, 'currenttime', 'currentTime'),
    (float, 'duration', 'duration'),
    (bool, 'paused', 'paused'),
    (float, 'defaultplaybackrate', 'defaultPlaybackRate'),
    (float, 'playbackrate', 'playbackRate'),
    (str, 'played', 'played'),
    (str, 'seekable', 'seekable'),
    (bool, 'ended', 'ended'),
    (bool, 'autoplay', 'autoplay'),
    (bool, 'loop', 'loop'),
    (bool, 'controls', 'controls'),
    (float, 'volume', 'volume'),
    (bool, 'muted', 'muted'),
    (bool, 'defaultmuted', 'defaultMuted'),
    (str, 'audiotracks', 'audioTracks'),
    (str, 'videotracks', 'videoTracks'),
    (str, 'texttracks', 'textTracks')
]

MediaCollection = []

Audio = []

AudioCollection = []

video = [
    (int, 'videowidth', 'videoWidth'),
    (int, 'videoheight', 'videoHeight'),
    (str, 'poster', 'poster')
]

VideoCollection = []

track = [
    (str, 'kind', 'kind'),
    (str, 'src', 'src'),
    (str, 'srclang', 'srclang'),
    (str, 'label', 'label'),
    (bool, 'default', 'default'),
    (int, 'readystate', 'readyState'),
    (str, 'track', 'track')
]

TrackCollection = []

param = [
    (str, 'name', 'name'),
    (str, 'value', 'value'),
    (str, 'type', 'type'),
    (str, 'valuetype', 'valueType')
]

ParamCollection = []

object = [
    (str, 'data', 'data'),
    (str, 'type', 'type'),
    (bool, 'typemustmatch', 'typeMustMatch'),
    (str, 'name', 'name'),
    (str, 'form', 'form'),
    (str, 'contentdocument', 'contentDocument'),
    (str, 'contentwindow', 'contentWindow'),
    (bool, 'willvalidate', 'willValidate'),
    (str, 'validity', 'validity'),
    (str, 'validationmessage', 'validationMessage'),
    (str, 'align', 'align'),
    (str, 'archive', 'archive'),
    (str, 'code', 'code'),
    (bool, 'declare', 'declare'),
    (int, 'hspace', 'hspace'),
    (str, 'standby', 'standby'),
    (int, 'vspace', 'vspace'),
    (str, 'codebase', 'codeBase'),
    (str, 'codetype', 'codeType'),
    (str, 'usemap', 'useMap'),
    (str, 'border', 'border')
]

ObjectCollection = []

embed = [
    (str, 'src', 'src'),
    (str, 'type', 'type'),
    (str, 'align', 'align'),
    (str, 'name', 'name')
]

EmbedCollection = []

iframe = [
    (str, 'src', 'src'),
    (str, 'srcdoc', 'srcdoc'),
    (str, 'name', 'name'),
    (str, 'sandbox', 'sandbox'),
    (bool, 'allowfullscreen', 'allowFullscreen'),
    (str, 'contentdocument', 'contentDocument'),
    (str, 'contentwindow', 'contentWindow'),
    (str, 'align', 'align'),
    (str, 'scrolling', 'scrolling'),
    (str, 'frameborder', 'frameBorder'),
    (str, 'marginheight', 'marginHeight'),
    (str, 'marginwidth', 'marginWidth')
]

IFrameCollection = []

image = [
    (str, 'alt', 'alt'),
    (str, 'src', 'src'),
    (str, 'srcset', 'srcset'),
    (str, 'sizes', 'sizes'),
    (str, 'crossorigin', 'crossOrigin'),
    (str, 'usemap', 'useMap'),
    (bool, 'ismap', 'isMap'),
    (int, 'naturalwidth', 'naturalWidth'),
    (int, 'naturalheight', 'naturalHeight'),
    (bool, 'complete', 'complete'),
    (str, 'currentsrc', 'currentSrc'),
    (str, 'name', 'name'),
    (str, 'lowsrc', 'lowsrc'),
    (str, 'align', 'align'),
    (int, 'hspace', 'hspace'),
    (int, 'vspace', 'vspace'),
    (str, 'border', 'border')
]

ImageCollection = []

source = [
    (str, 'srcset', 'srcset'),
    (str, 'sizes', 'sizes'),
    (str, 'media', 'media'),
    (str, 'src', 'src'),
    (str, 'type', 'type')
]

SourceCollection = []

Picture = []

PictureCollection = []

mod = [
    (str, 'cite', 'cite'),
    (str, 'datetime', 'dateTime')
]

ModCollection = []

br = [
    (str, 'clear', 'clear')
]

BRCollection = []

Span = []

SpanCollection = []

time = [
    (str, 'datetime', 'dateTime')
]

TimeCollection = []

data = [
    (str, 'value', 'value')
]

DataCollection = []

anchor = [
    (str, 'target', 'target'),
    (str, 'download', 'download'),
    (str, 'rel', 'rel'),
    (str, 'rev', 'rev'),
    (str, 'rellist', 'relList'),
    (str, 'hreflang', 'hreflang'),
    (str, 'type', 'type'),
    (str, 'coords', 'coords'),
    (str, 'charset', 'charset'),
    (str, 'name', 'name'),
    (str, 'shape', 'shape'),
    (str, 'href', 'href'),
    (str, 'origin', 'origin'),
    (str, 'protocol', 'protocol'),
    (str, 'username', 'username'),
    (str, 'password', 'password'),
    (str, 'host', 'host'),
    (str, 'hostname', 'hostname'),
    (str, 'port', 'port'),
    (str, 'pathname', 'pathname'),
    (str, 'search', 'search')
]

AnchorCollection = []

div = [
    (str, 'align', 'align')
]

DivCollection = []

dlist = [
    (bool, 'compact', 'compact')
]

DListCollection = []

li = [
    (int, 'value', 'value'),
    (str, 'type', 'type')
]

LICollection = []

ulist = [
    (bool, 'compact', 'compact'),
    (str, 'type', 'type')
]

UListCollection = []

olist = [
    (bool, 'reversed', 'reversed'),
    (int, 'start', 'start'),
    (str, 'type', 'type'),
    (bool, 'compact', 'compact')
]

OListCollection = []

quote = [
    (str, 'cite', 'cite')
]

QuoteCollection = []

Pre = []

PreCollection = []

hr = [
    (str, 'align', 'align'),
    (str, 'color', 'color'),
    (bool, 'noshade', 'noShade')
]

HRCollection = []

paragraph = [
    (str, 'align', 'align')
]

ParagraphCollection = []

heading = [
    (str, 'align', 'align')
]

HeadingCollection = []

body = [
    (str, 'link', 'link'),
    (str, 'vlink', 'vLink'),
    (str, 'alink', 'aLink'),
    (str, 'bgcolor', 'bgColor'),
    (str, 'background', 'background'),
    (str, 'onafterprint', 'onafterprint'),
    (str, 'onbeforeprint', 'onbeforeprint'),
    (str, 'onbeforeunload', 'onbeforeunload'),
    (str, 'onhashchange', 'onhashchange'),
    (str, 'onlanguagechange', 'onlanguagechange'),
    (str, 'onmessage', 'onmessage'),
    (str, 'onoffline', 'onoffline'),
    (str, 'ononline', 'ononline'),
    (str, 'onpagehide', 'onpagehide'),
    (str, 'onpageshow', 'onpageshow'),
    (str, 'onrejectionhandled', 'onrejectionhandled'),
    (str, 'onpopstate', 'onpopstate'),
    (str, 'onstorage', 'onstorage'),
    (str, 'onunhandledrejection', 'onunhandledrejection'),
    (str, 'onunload', 'onunload')
]

BodyCollection = []

style = [
    (str, 'media', 'media'),
    (str, 'nonce', 'nonce'),
    (str, 'type', 'type')
]

StyleCollection = []

meta = [
    (str, 'name', 'name'),
    (str, 'http_equiv', 'httpEquiv'),
    (str, 'content', 'content'),
    (str, 'scheme', 'scheme')
]

MetaCollection = []

base = [
    (str, 'href', 'href'),
    (str, 'target', 'target')
]

BaseCollection = []

Title = []

TitleCollection = []

Head = []

HeadCollection = []

html = [
    (str, 'version', 'version')
]

HtmlCollection = []

Unknown = []

UnknownCollection = []
