# Autogenerated from SVG specification. Edits may be lost.

svgelement = [
    (str, 'classname', 'className'),
    (str, 'dataset', 'dataset'),
    (str, 'ownersvgelement', 'ownerSVGElement'),
    (str, 'viewportelement', 'viewportElement'),
    (int, 'tabindex', 'tabIndex'),
    (str, 'correspondingelement', 'correspondingElement'),
    (str, 'correspondinguseelement', 'correspondingUseElement')
]

SVGElementCollection = []

view = [
    (str, 'viewbox', 'viewBox'),
    (str, 'preserveaspectratio', 'preserveAspectRatio'),
    (int, 'zoomandpan', 'zoomAndPan')
]

ViewCollection = []

cursor = [
    (int, 'x', 'x'),
    (int, 'y', 'y'),
    (str, 'href', 'href')
]

CursorCollection = []

Hatchpath = []

HatchpathCollection = []

Hatch = []

HatchCollection = []

pattern = [
    (str, 'patternunits', 'patternUnits'),
    (str, 'patterncontentunits', 'patternContentUnits'),
    (str, 'patterntransform', 'patternTransform'),
    (int, 'x', 'x'),
    (int, 'y', 'y'),
    (int, 'width', 'width'),
    (int, 'height', 'height'),
    (str, 'viewbox', 'viewBox'),
    (str, 'preserveaspectratio', 'preserveAspectRatio'),
    (str, 'href', 'href')
]

PatternCollection = []

stop = [
    (str, 'offset', 'offset')
]

StopCollection = []

Meshpatch = []

MeshpatchCollection = []

Meshrow = []

MeshrowCollection = []

gradient = [
    (str, 'gradientunits', 'gradientUnits'),
    (str, 'gradienttransform', 'gradientTransform'),
    (str, 'spreadmethod', 'spreadMethod'),
    (str, 'href', 'href')
]

GradientCollection = []

MeshGradient = []

MeshGradientCollection = []

radialgradient = [
    (int, 'cx', 'cx'),
    (int, 'cy', 'cy'),
    (int, 'r', 'r'),
    (int, 'fx', 'fx'),
    (int, 'fy', 'fy'),
    (int, 'fr', 'fr')
]

RadialGradientCollection = []

lineargradient = [
    (int, 'x1', 'x1'),
    (int, 'y1', 'y1'),
    (int, 'x2', 'x2'),
    (int, 'y2', 'y2')
]

LinearGradientCollection = []

Solidcolor = []

SolidcolorCollection = []

marker = [
    (int, 'refx', 'refX'),
    (int, 'refy', 'refY'),
    (str, 'markerunits', 'markerUnits'),
    (int, 'markerwidth', 'markerWidth'),
    (int, 'markerheight', 'markerHeight'),
    (str, 'orienttype', 'orientType'),
    (str, 'orientangle', 'orientAngle'),
    (str, 'orient', 'orient'),
    (str, 'viewbox', 'viewBox'),
    (str, 'preserveaspectratio', 'preserveAspectRatio')
]

MarkerCollection = []

Metadata = []

MetadataCollection = []

Desc = []

DescCollection = []

graphics = [
    (str, 'transform', 'transform'),
    (str, 'requiredextensions', 'requiredExtensions'),
    (str, 'systemlanguage', 'systemLanguage')
]

GraphicsCollection = []

foreignobject = [
    (int, 'x', 'x'),
    (int, 'y', 'y'),
    (int, 'width', 'width'),
    (int, 'height', 'height')
]

ForeignObjectCollection = []

textcontent = [
    (int, 'textlength', 'textLength'),
    (str, 'lengthadjust', 'lengthAdjust')
]

TextContentCollection = []

textpath = [
    (int, 'startoffset', 'startOffset'),
    (str, 'method', 'method'),
    (str, 'spacing', 'spacing'),
    (str, 'href', 'href')
]

TextPathCollection = []

textpositioning = [
    (str, 'x', 'x'),
    (str, 'y', 'y'),
    (str, 'dx', 'dx'),
    (str, 'dy', 'dy'),
    (str, 'rotate', 'rotate')
]

TextPositioningCollection = []

TSpan = []

TSpanCollection = []

Switch = []

SwitchCollection = []

use = [
    (int, 'x', 'x'),
    (int, 'y', 'y'),
    (int, 'width', 'width'),
    (int, 'height', 'height'),
    (str, 'instanceroot', 'instanceRoot'),
    (str, 'animatedinstanceroot', 'animatedInstanceRoot'),
    (str, 'href', 'href')
]

UseCollection = []

symbol = [
    (str, 'viewbox', 'viewBox'),
    (str, 'preserveaspectratio', 'preserveAspectRatio')
]

SymbolCollection = []

Defs = []

DefsCollection = []

G = []

GCollection = []

svg = [
    (int, 'x', 'x'),
    (int, 'y', 'y'),
    (int, 'width', 'width'),
    (int, 'height', 'height'),
    (float, 'currentscale', 'currentScale'),
    (str, 'currenttranslate', 'currentTranslate'),
    (str, 'viewbox', 'viewBox'),
    (str, 'preserveaspectratio', 'preserveAspectRatio'),
    (int, 'zoomandpan', 'zoomAndPan')
]

SVGCollection = []

geometry = [
    (str, 'pathlength', 'pathLength')
]

GeometryCollection = []

polygon = [
    (str, 'points', 'points'),
    (str, 'animatedpoints', 'animatedPoints')
]

PolygonCollection = []

polyline = [
    (str, 'points', 'points'),
    (str, 'animatedpoints', 'animatedPoints')
]

PolylineCollection = []

mesh = [
    (str, 'href', 'href')
]

MeshCollection = []

line = [
    (int, 'x1', 'x1'),
    (int, 'y1', 'y1'),
    (int, 'x2', 'x2'),
    (int, 'y2', 'y2')
]

LineCollection = []

ellipse = [
    (int, 'cx', 'cx'),
    (int, 'cy', 'cy'),
    (int, 'rx', 'rx'),
    (int, 'ry', 'ry')
]

EllipseCollection = []

circle = [
    (int, 'cx', 'cx'),
    (int, 'cy', 'cy'),
    (int, 'r', 'r')
]

CircleCollection = []

rect = [
    (int, 'x', 'x'),
    (int, 'y', 'y'),
    (int, 'width', 'width'),
    (int, 'height', 'height'),
    (int, 'rx', 'rx'),
    (int, 'ry', 'ry')
]

RectCollection = []

Path = []

PathCollection = []
